# Changelog

## [0.3.0](https://github.com/Maxl94/yaai/compare/v0.2.3...v0.3.0) (2026-02-23)


### Features

* add Google user ID token auth and scale dashboard to 1.8M+ records ([9d006be](https://github.com/Maxl94/yaai/commit/9d006be871b25b22c84f2981b56e4bf437a9e496))

## [0.2.3](https://github.com/Maxl94/yaai/compare/v0.2.2...v0.2.3) (2026-02-20)


### Bug Fixes

* add automatic migration on startup ([0023ee3](https://github.com/Maxl94/yaai/commit/0023ee32924f0f3c8974f810dd659c96901a43ef))
* improves logging ([4751277](https://github.com/Maxl94/yaai/commit/47512770703e62f6d6f926404e8462eb01c81add))

## [0.2.2](https://github.com/Maxl94/yaai/compare/v0.2.1...v0.2.2) (2026-02-20)


### Bug Fixes

* adds default role to role check ([2d5b384](https://github.com/Maxl94/yaai/commit/2d5b38423897be8229a027a0daf75d56765e4bb7))

## [0.2.1](https://github.com/Maxl94/yaai/compare/v0.2.0...v0.2.1) (2026-02-20)


### Bug Fixes

* fixes issue with loop for cloud sql iam authentication ([8c351ef](https://github.com/Maxl94/yaai/commit/8c351ef9f07c749afe67197fc3d9447c5a9f140e))
* improve warning for default DB credentials to include Cloud SQL connector check ([cf34f3f](https://github.com/Maxl94/yaai/commit/cf34f3f7b3713d2526c9793655376d1b17156c77))


### Documentation

* adds google service account settings ([921be06](https://github.com/Maxl94/yaai/commit/921be0698afa1eafc31701fe5450deed977dd2f3))

## [0.2.0](https://github.com/Maxl94/yaai/compare/v0.1.7...v0.2.0) (2026-02-20)


### Features

* add Cloud SQL connector and unify auth/database configuration ([4a80588](https://github.com/Maxl94/yaai/commit/4a8058825a1b8785d34b2f5c79c0e3ff997c4e03))

## [0.1.7](https://github.com/Maxl94/yaai/compare/v0.1.6...v0.1.7) (2026-02-19)


### Bug Fixes

* removes rm command in release actions ([0a3d0d9](https://github.com/Maxl94/yaai/commit/0a3d0d962a5815767706705eb52c467fd9d91433))

## [0.1.6](https://github.com/Maxl94/yaai/compare/v0.1.5...v0.1.6) (2026-02-19)


### Bug Fixes

* adds missing description to dockerfile ([5413ceb](https://github.com/Maxl94/yaai/commit/5413cebf1f6b07e1f0d5e7ab1d7063b6083c9da5))

## [0.1.5](https://github.com/Maxl94/yaai/compare/v0.1.4...v0.1.5) (2026-02-19)


### Bug Fixes

* adds static files as build artifact ([426c76a](https://github.com/Maxl94/yaai/commit/426c76ab90ad222c6ec492f5c89090cf589b4705))

## [0.1.4](https://github.com/Maxl94/yaai/compare/v0.1.3...v0.1.4) (2026-02-19)


### Bug Fixes

* adds missing frontend to python wheel and adds dockerfiles for testing ([5054fae](https://github.com/Maxl94/yaai/commit/5054faef8ab30796e109544236940cc81e29fdb7))

## [0.1.3](https://github.com/Maxl94/yaai/compare/v0.1.2...v0.1.3) (2026-02-19)


### Bug Fixes

* adds missing alembic files to package ([7a84792](https://github.com/Maxl94/yaai/commit/7a84792519622ac3f237adee82c1357bdd288c58))

## [0.1.2](https://github.com/Maxl94/yaai/compare/v0.1.1...v0.1.2) (2026-02-19)


### Bug Fixes

* updates alembic configuration and adjusts paths in main.py ([2c6ee40](https://github.com/Maxl94/yaai/commit/2c6ee40595ec9105257fa76423851db320a8de44))

## [0.1.1](https://github.com/Maxl94/yaai/compare/v0.1.0...v0.1.1) (2026-02-16)


### Documentation

* corrects package name ([319ca9d](https://github.com/Maxl94/yaai/commit/319ca9d673476a1d6e7845dd86e63bf2983d69ba))
* update install commands and fix build for yaai-monitoring rename ([88a9921](https://github.com/Maxl94/yaai/commit/88a992117a0a975778ca6faca428390feed9ce21))

## [0.1.0](https://github.com/Maxl94/yaai/compare/v0.1.0...v0.1.0) (2026-02-16)


### Features

* initial release of YAAI platform ([0662d48](https://github.com/Maxl94/yaai/commit/0662d48b222c61be92b36490b675182b69dcddb7))


### Documentation

* adds license and contribution guide ([6b43d92](https://github.com/Maxl94/yaai/commit/6b43d92573690c789ebcaa904971ebab8559dfb7))
* adds logo and screenshots ([aed0900](https://github.com/Maxl94/yaai/commit/aed0900bbbe14e253f8c23434e4f17df70a00aed))
* adds readme ([0b88f1e](https://github.com/Maxl94/yaai/commit/0b88f1e6a8f24c52b404f5eff2062bf0aa9d6200))
* updates screenshots ([3399ac3](https://github.com/Maxl94/yaai/commit/3399ac308d42cf9f57f1b6f8b335c92826826b19))


### Miscellaneous Chores

* rename package to align with PyPI ([fdad286](https://github.com/Maxl94/yaai/commit/fdad2865a091c13545e08867a7ceec3d72b68ee6))

## [0.1.0](https://github.com/Maxl94/yaai/compare/v0.1.0...v0.1.0) (2026-02-16)


### Miscellaneous Chores

* rename package to align with PyPI ([fdad286](https://github.com/Maxl94/yaai/commit/fdad2865a091c13545e08867a7ceec3d72b68ee6))

## 0.1.0 (2026-02-16)


### Features

* initial release of YAAI platform ([0662d48](https://github.com/Maxl94/yaai/commit/0662d48b222c61be92b36490b675182b69dcddb7))


### Documentation

* adds license and contribution guide ([6b43d92](https://github.com/Maxl94/yaai/commit/6b43d92573690c789ebcaa904971ebab8559dfb7))
* adds logo and screenshots ([aed0900](https://github.com/Maxl94/yaai/commit/aed0900bbbe14e253f8c23434e4f17df70a00aed))
* adds readme ([0b88f1e](https://github.com/Maxl94/yaai/commit/0b88f1e6a8f24c52b404f5eff2062bf0aa9d6200))
* updates screenshots ([3399ac3](https://github.com/Maxl94/yaai/commit/3399ac308d42cf9f57f1b6f8b335c92826826b19))
